@@ -5,6 +5,6 @@ Kurtosis = function(y)
   y = y[!is.na(y)]
   n = length(y)
   if (n < 4) return(NA) # stop("Input vector length should be larger than 3.")
-  d = y - mean(y)
+  d = y - mean(y, na.rm=T)
   n*(n + 1)*sum(d^4)/((n - 1)*(n - 2)*(n - 3)*(sum(d^2)/(n - 1))^2) - 3*(n - 1)^2/((n - 2)*(n - 3))
 }
