@@ -1,4 +1,4 @@
-aov2 = function(Formula, Data)
+aov2 = function(Formula, Data, BETA=FALSE, Resid=FALSE)
 {
   if (!attr(terms(Formula, data=Data), "response")) {
     stop("Dependent variable should be provided!")
@@ -26,8 +26,30 @@ aov2 = function(Formula, Data)
 
   if (fAdj) rx$coefficients = rx$coefficients*vESTM
   Tx = SS(x1, rx, Lx)
-
   SST = as.numeric(crossprod(y - attr(x0$terms, "intercept")*mean(y)))
+  Res0 = sumANOVA(rx, Tx, SST, nrow(x0$X), rownames(attr(terms(x0), "factors"))[1])
 
-  return(sumANOVA(rx, Tx, SST, NROW(x0$X), rownames(attr(terms(x0), "factors"))[1]))
+  if (!BETA & !Resid) {
+    Result = Res0
+  } else {
+    Result = list(ANOVA=Res0)
+    iNext = 2
+
+    if (BETA) {
+      Result[[iNext]] = sumREG(rx, x1$X)
+      names(Result)[iNext] = "Parameter"
+      iNext = iNext + 1
+    }
+
+    if (Resid) {
+      yhat = as.numeric(x1$X %*% rx$coefficients)
+      Result[[iNext]] = yhat
+      names(Result)[iNext] = "Fitted"
+
+      Result[[iNext + 1]] = y - yhat
+      names(Result)[iNext + 1] = "Residual"
+    }
+  }
+
+  return(Result)
 }
